@@ -26,9 +26,9 @@ class TrainArguments:
         default=None,
         metadata={"help": "The name of the downstream data."}
     )
-    downstream_corpus_dir: str = field(
-        default=None,
-        metadata={"help": "The input corpus dir. Should contain the .txt files (or other data files) for the task."}
+    downstream_corpus_root_dir: str = field(
+        default="/root/Korpora",
+        metadata={"help": "The root directory of the downstream data."}
     )
     downstream_task_name: str = field(
         default=None,
@@ -61,10 +61,6 @@ class TrainArguments:
         default=7,
         metadata={"help": "random seed."}
     )
-    data_cache_dir: str = field(
-        default=None,
-        metadata={"help": "Where do you want to store the cached data"}
-    )
     overwrite_cache: bool = field(
         default=False,
         metadata={"help": "Overwrite the cached training and evaluation sets"}
