@@ -42,8 +42,7 @@ class NsmcCorpus:
         for (i, line) in enumerate(lines):
             if i == 0:
                 continue
-            text_a = line[1]
-            label = None if set_type == "test" else line[2]
+            _, text_a, label = line
             examples.append(ClassificationExample(text_a=text_a, text_b=None, label=label))
         return examples
 
